clear all
set more off
capture log close
set matsize 11000
cap mat drop
#delimit ;

*--------------------------------------------------------------
* global macro path definitions:
*--------------------------------------------------------------

global d=0;

if $d==0 {;
global PATH "Your path here/";
global DATA "${PATH}data/";
global LOGS "${PATH}log/";
global TABLES "${PATH}table/";
global GRAPHS "${PATH}graph/";
};


log using "${LOGS}graphs&tables.log", replace;

use "${DATA}replication.dta", clear;


// Varibale creating and labeling

egen hh_id=group(hh_a01 hh_a02 hh_a03 hh_a06);
egen ea_id=group(hh_a01 hh_a02 hh_a03);
egen ea_tag=tag(ea_id round);

recode region (1 = 1) (2 3 = 0), gen(north);
recode region (2 = 1) (1 3 = 0), gen(central);
recode region (3 = 1) (1 2 = 0), gen(south);

label var north "North";
label var central "Central";
label var south "South";
label var pwp "Control households in treatment villages";
label var lean "Control households in lean treatment villages";
label var harvest "Control households in harvest treatment villages";
label var topup_pwp "Treatment households";
label var topup_lean "Lean treatment households";
label var topup_harvest "Harvest treatment households";

foreach var in north central south {;
	gen pwp_`var' = pwp * `var';
	gen lean_`var' = lean * `var';
	gen harvest_`var' = harvest * `var';
	gen topup_pwp_`var' = topup_pwp * `var';
	gen topup_lean_`var' = topup_lean * `var';
	gen topup_harvest_`var' = topup_harvest * `var';
	};

label var pwp_north "Control households in treatment villages (North)";
label var pwp_central "Control households in treatment villages (Central)";
label var pwp_south "Control households in treatment villages (South)";
label var lean_north "Control households in lean treatment villages (North)";
label var lean_central "Control households in lean treatment villages (Central)";
label var lean_south "Control households in lean treatment villages (South)";
label var harvest_north "Control households in harvest treatment villages (North)";
label var harvest_central "Control households in harvest treatment villages (Central)";
label var harvest_south "Control households in harvest treatment villages (South)";

label var topup_pwp_north "Treatment households (North)";
label var topup_pwp_central "Treatment households (Central)";
label var topup_pwp_south "Treatment households (South)";
label var topup_lean_north "Lean treatment households (North)";
label var topup_lean_central "Lean treatment households (Central)";
label var topup_lean_south "Lean treatment households (South)";	
label var topup_harvest_north "Harvest treatment households (North)";
label var topup_harvest_central "Harvest treatment households (Central)";
label var topup_harvest_south "Harvest treatment households (South)";

	
gen tany_hired=0 if round==0;
replace tany_hired=1 if allhired_days>0 & round==0;

bys hh_id: egen any_hired=max(tany_hired);
label var any_hired "Any hired labor in previous season";

gen pwp_hired=pwp*any_hired;
gen pwp_nohired=pwp;
replace pwp_nohired=0 if any_hired==1;

gen topup_pwp_hired=topup_pwp*any_hired;
gen topup_pwp_nohired=topup_pwp;
replace topup_pwp_nohired=0 if any_hired==1;

label var pwp_hired "Control households in treatment villages (Hired labor)";
label var pwp_nohired "Control households in treatment villages (No hired labor)";
label var topup_pwp_hired "Treatment households (Hired labor)";
label var topup_pwp_nohired "Treatment households (No hired labor)";

gen headSecondSchool = (headEducation>=9);
replace headSecondSchool = . if headEducation==.;

*--------------------------------------------------------------------------------------
* FOOD SECURITY INDEX
*--------------------------------------------------------------------------------------;


foreach var in reduceMeal foodSecurityIHS foodCopingStrat {;
	gen inv_`var'=-1*`var';
	};

gen shortfs_score=.;
forval t=0/4 {;	

	pca logpc_foodexp logpc_foodcons1 foodConsumpScore caloriesDayAE foodDiversity inv_reduceMeal inv_foodSecurityIHS inv_foodCopingStrat if round==`t';
	predict shortfs_score_`t';
	
	replace shortfs_score=shortfs_score_`t' if round==`t';
	drop shortfs_score_`t';
	
	};




*--------------------------------------------------------------------------------------
* DEFINITION OF OUTCOMES FOR TABLES
*--------------------------------------------------------------------------------------
;

global longfam_1 "daysGanyu logpc_foodexp logpc_foodcons1 foodConsumpScore caloriesDayAE foodDiversity inv_reduceMeal inv_foodSecurityIHS inv_foodCopingStrat shortfs_score";
global longfam_2 "daysMasaf";

global longfam_3 "logqkgFert1_transf logqkgFert2_transf anyFert anyDurables numDurables durableScore";
global longfam_4 "logexpFert1_transf logexpFert2_transf";

global longfam_5 "anyFreeFood anyNutrition anyScholarship anyCashTransfer";
global longfam_6 "anyCouponFert anyTransIn anyTransOut anyCalLoansIn anyLoanPayments";

global longfam_X "daysGanyu logpc_foodcons1 foodConsumpScore caloriesDayAE foodDiversity inv_foodSecurityIHS inv_foodCopingStrat shortfs_score";



************************************************************************************
* STEP 0 - DESCRIPTIVES
***********************************************************************************;

// table 2


global longfam_7 "headFemale headEducation headSecondSchool HHsize HHchildCount";
global longfam_Y "HHsize headFemale headSecondSchool anyDurables durableScore anyFert logqkgFert1_transf logqkgFert2_transf anyScholarship anyCashTransfer";


forval num=1/7 {;

	forval t=1/3 {;

	display `num';
	local listname longfam_`num';
    local vlist "${`listname'}";
	if (!missing("`vlist'") & round==`t')  tabstat ${longfam_`num'}, s(p10 p50 mean p90 sd min max n) col(stat);
	display "--------------FAMILY `num' AND ROUND `t' -------------------------------";
	if (!missing("`vlist'") & round==`t')  tabstat ${longfam_`num'}, s(mean sd) col(stat);
	};
};



****  PANEL SET UP TO CREATE BASELINE VALUES;


tsset hh_id round;
xtdes;

gen week=week(date_survey);
gen year=year(date_survey);

foreach var of varlist $longfam_1 $longfam_3 $longfam_5 $longfam_7 rlogpc_fcons1 {;
		gen `var'_0=`var' if round==0;
		egen BL_`var'_t = mean(`var'_), by(hh_id);
		qui reg BL_`var'_t i.week i.year if round==0;
		predict yhat_`var' if e(samp), res;
		egen BL_`var' = mean(yhat_`var'), by(hh_id);
		drop `var'_0 yhat_`var' BL_`var'_t;
		};

global longfam_8 "BL_headFemale BL_headEducation BL_headSecondSchool BL_HHsize BL_HHchildCount";
		
		
foreach var of varlist $longfam_1 $longfam_3 $longfam_5 {;
		gen BL_`var'_north = BL_`var' * north;
		gen BL_`var'_central = BL_`var' * central;
		gen BL_`var'_south = BL_`var' * south;
		};


		
*************************************************;
***** Graphs  ***********************************;
*************************************************;


// Figure 3: National targeting based on IHS3 food security;

twoway lowess anyMasaf BL_rlogpc_fcons1 if round==2 & pwp==1 & topup==0 , lcolor(black)  lwidth(medthick)   bwidth(.4) ||   
     lowess  anyMasaf BL_rlogpc_fcons1 if round==2 & pwp==1 & topup==1 ,  lpattern(longdash_dot) lcolor(black) lwidth(medthick) bwidth(.4)
		saving("${GRAPHS}figure3.png", replace) 
	title("MASAF participation during the lean season (round 2)", pos(11) color(black) size(medium)) 
	ylabel(0(.2)1,  grid)
	xlabel(-2(1)2)
	xtitle("Log per capita food consumption, IHS-3",  size(mediumsmall))
	ytitle("MASAF participation",  size(mediumsmall))
	legend(region(margin(vsmall))) graphregion(fcolor(white) lcolor(black)) plotregion(lcolor(black))
	legend(cols(1) order(2 "treated hh'lds" 1 "untreated hh'lds" ) size(small))
	legend(position(1) ring(0))	;

// Figure 4: Regional targeting based on IHS3 food security;

forval num=1/3 {;

preserve;

keep if region==`num';
if `num'==1 {; local r="North" ; };
if `num'==2 {; local r="Center" ; };
if `num'==3 {; local r="South" ; };


twoway lowess anyMasaf BL_rlogpc_fcons1 if round==2 & pwp==1 & topup==0 , lcolor(black)  lwidth(medthick)   bwidth(.4) ||   
     lowess  anyMasaf BL_rlogpc_fcons1 if round==2 & pwp==1 & topup==1 ,  lpattern(longdash_dot) lcolor(black) lwidth(medthick) bwidth(.4)
	ytitle("MASAF participation",  size(mediumsmall))
	xtitle("Log per capita food consumption, IHS-3",  size(mediumsmall))
	ytitle("MASAF participation",  size(mediumsmall))		 	
	title("`r'", color(black) size(medium)) 
	saving("${GRAPHS}figure4_`num'.gph", replace)  
	ylabel(0(.2)1,  grid) 
	xlabel(-2(1)2)
	legend(off); 
	
	
restore;
};

graph combine "${GRAPHS}figure4_1"  "${GRAPHS}figure4_2"  "${GRAPHS}figure4_3", title("Targeting  round 2 (lean season), by region", size(medium)) saving("${GRAPHS}figure4.png", replace) xcommon;
graph drop _all;
		

*************************************************;
***** Tables  ***********************************;
*************************************************;


/*-------- Balance Test (IHS3) -----------------------------------------------*/;

// Table 3: Food Security and Labor Supply;

	preserve;
	keep if round==0;
	
	*looping over food security and labor supply outcomes;
	foreach var of varlist $longfam_X {;
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}table3.tex", replace 
		style(tex)
		keep(topup_pwp pwp)
		numbers label
		title("Table 3.  Balance Test on Food Security and Labor Supply (IHS3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;

	restore;
	
	estimates clear;

			
			
/*-------- ITT ---------------------------------------------------------------*/;

// Table 4: Round 2 and 3 (including baseline controls);
	
	// Round 2
	preserve;
	keep if round==2;
		
		
		foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		
		foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp BL_`var'  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};

	estout EST_* using "${TABLES}table4.tex", replace 
		style(tex)
		keep(topup_pwp pwp)
		numbers label
		title("Table 4.  ITT on Food Security and Labor Supply, with Baseline Controls (Round 2 and 3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;
	
	// Round 3
	preserve;
	keep if round==3;

	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' lean topup_lean harvest topup_harvest i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test lean + topup_lean = harvest + topup_harvest;
			estadd scalar p=r(p);
			
			foreach y in lean harvest {;
			
			test `y' + topup_`y'=0;
			local p_`y'=r(p);
			
			nlcom _b[`y']+_b[topup_`y'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[`y']+_b[topup_`y'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`y''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`y''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`y''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`y'_se = temp_se;
			estadd local tot_`y' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			
			};
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			
			};
		drop mean_`var';
		};
			
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' lean topup_lean harvest topup_harvest BL_`var' i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			
			test lean + topup_lean = harvest + topup_harvest;
			estadd scalar p=r(p);
			
			foreach y in lean harvest {;
			
			test `y' + topup_`y'=0;
			local p_`y'=r(p);		
			
			nlcom _b[`y']+_b[topup_`y'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[`y']+_b[topup_`y'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`y''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`y''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`y''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`y'_se = temp_se;
			estadd local tot_`y' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			};
		
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			
			};
		drop mean_`var';
		};
		

	estout EST_* using "${TABLES}table4.tex", append 
		style(tex)
		keep(lean topup_lean harvest topup_harvest)
		numbers label
		title("Table 4.  ITT on Food Security and Labor Supply, with Baseline Controls (Round 2 and 3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot_lean tot_lean_se tot_harvest tot_harvest_se p mean_y sd_y r2 N, fmt(3 3 3 3 2 2 2 2 0) 
		labels("Difference: lean treatment households vs. households in control villages" " " "Difference: harvest treatment households vs. households in control villages" " " 
				"p-value: equal effects on lean treatment HHs and harvest treatment HHs" "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;

	
// Table 5: Round 2, by Region (including baseline controls);

	preserve;
	keep if round==2;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp_north = pwp_central = pwp_south;
			estadd scalar p_pwp = r(p);
			test topup_pwp_north = topup_pwp_central = topup_pwp_south;
			estadd scalar p_topup_pwp = r(p);
			
			foreach x in north central south {;
			
			test pwp_`x'+topup_pwp_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[pwp_`x']+_b[topup_pwp_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp_`x']+_b[topup_pwp_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			
			qui sum `var' if e(sample) & pwp==0 & `x'==1;
			estadd scalar mean_y_`x'=r(mean);
			estadd scalar sd_y_`x'=r(sd);
			
			};
			
			};
		drop mean_`var';
		};
			
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south BL_`var' BL_`var'_north BL_`var'_central BL_`var'_south i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp_north = pwp_central = pwp_south;
			estadd scalar p_pwp = r(p);
			test topup_pwp_north = topup_pwp_central = topup_pwp_south;
			estadd scalar p_topup_pwp = r(p);
			
			foreach x in north central south {;
			
			test pwp_`x'+topup_pwp_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[pwp_`x']+_b[topup_pwp_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp_`x']+_b[topup_pwp_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			
			qui sum `var' if e(sample) & pwp==0 & `x'==1;
			estadd scalar mean_y_`x'=r(mean);
			estadd scalar sd_y_`x'=r(sd);
			
			};
			
			};
		drop mean_`var';
		};
		

	estout EST_* using "${TABLES}table5.tex", replace 
		style(tex)
		keep(pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south)
		numbers label
		title("Table 5.  ITT on Food Security and Labor Supply by Region (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot_north tot_north_se tot_central tot_central_se tot_south tot_south_se p_pwp p_topup_pwp mean_y_north sd_y_north mean_y_central sd_y_central mean_y_south sd_y_south r2 N, fmt(3 3 3 3 3 3 2 2 2 2 2 2 2 2 2 0) 
		labels("Difference: treatment households vs. households in control villages (North)" " " "Difference: treatment households vs. households in control villages (Central)" " " "Difference: treatment households vs. households in control villages (South)" " " 
		"p-value: all three regions have equal effects on control households in treatment villages" "p-value: all three regions have equal effects on treatment households"
		"Mean of dep. var. in control villages (North)" "S.D. of dep. var. in control villages (North)"
		"Mean of dep. var. in control villages (Central)" "S.D. of dep. var. in control villages (Central)"
		"Mean of dep. var. in control villages (South)" "S.D. of dep. var. in control villages (South)" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;	
	
	
// Table 6: Round 3, by Region (including baseline controls);

	preserve;
	keep if round==3;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' lean_north topup_lean_north harvest_north topup_harvest_north lean_central topup_lean_central harvest_central topup_harvest_central lean_south harvest_south topup_lean_south topup_harvest_south i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test lean_north = lean_central = lean_south;
			estadd scalar p_lean = r(p);
			test harvest_north = harvest_central = harvest_south;
			estadd scalar p_harvest = r(p);
			test topup_lean_north = topup_lean_central = topup_lean_south;
			estadd scalar p_topup_lean = r(p);
			test topup_harvest_north = topup_harvest_central = topup_harvest_south;
			estadd scalar p_topup_harvest = r(p);
			
			test lean_north + topup_lean_north = harvest_north + topup_harvest_north;
			estadd scalar p_north = r(p);
			test lean_central + topup_lean_central = harvest_central + topup_harvest_central;
			estadd scalar p_central = r(p);
			test lean_south + topup_lean_south = harvest_south + topup_harvest_south;
			estadd scalar p_south = r(p);	
			
			foreach x in north central south {;
			foreach y in lean harvest {;
			
			test `y'_`x'+topup_`y'_`x'=0;
			local p_`y'_`x'=r(p);
			
			nlcom _b[`y'_`x']+_b[topup_`y'_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[`y'_`x']+_b[topup_`y'_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`y'_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`y'_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`y'_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`y'_`x'_se = temp_se;
			estadd local tot_`y'_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			
			};
			
			qui sum `var' if e(sample) & pwp==0 & `x'==1;
			estadd scalar mean_y_`x'=r(mean);
			estadd scalar sd_y_`x'=r(sd);
			
			};
			
			};
		drop mean_`var';
		};
			
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' lean_north topup_lean_north harvest_north topup_harvest_north lean_central topup_lean_central harvest_central topup_harvest_central lean_south harvest_south topup_lean_south topup_harvest_south BL_`var' BL_`var'_north BL_`var'_central BL_`var'_south i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			
			test lean_north = lean_central = lean_south;
			estadd scalar p_lean = r(p);
			test harvest_north = harvest_central = harvest_south;
			estadd scalar p_harvest = r(p);
			test topup_lean_north = topup_lean_central = topup_lean_south;
			estadd scalar p_topup_lean = r(p);
			test topup_harvest_north = topup_harvest_central = topup_harvest_south;
			estadd scalar p_topup_harvest = r(p);
			
			test lean_north + topup_lean_north = harvest_north + topup_harvest_north;
			estadd scalar p_north = r(p);
			test lean_central + topup_lean_central = harvest_central + topup_harvest_central;
			estadd scalar p_central = r(p);
			test lean_south + topup_lean_south = harvest_south + topup_harvest_south;
			estadd scalar p_south = r(p);	
			
			foreach x in north central south {;
			foreach y in lean harvest {;
			
			test `y'_`x'+topup_`y'_`x'=0;
			local p_`y'_`x'=r(p);
			
			nlcom _b[`y'_`x']+_b[topup_`y'_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[`y'_`x']+_b[topup_`y'_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`y'_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`y'_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`y'_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`y'_`x'_se = temp_se;
			estadd local tot_`y'_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			
			};
			
			qui sum `var' if e(sample) & pwp==0 & `x'==1;
			estadd scalar mean_y_`x'=r(mean);
			estadd scalar sd_y_`x'=r(sd);
			
			};
			
			};
		drop mean_`var';
		};
		


	estout EST_* using "${TABLES}table6.tex", replace 
		style(tex)
		keep(lean_north topup_lean_north harvest_north topup_harvest_north lean_central topup_lean_central harvest_central topup_harvest_central lean_south topup_lean_south harvest_south topup_harvest_south)
		numbers label
		title("Table 6.  ITT on Food Security and Labor Supply by Region (Round 3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot_lean_north tot_lean_north_se tot_harvest_north tot_harvest_north_se 
		tot_lean_central tot_lean_central_se tot_harvest_central tot_harvest_central_se  
		tot_lean_south tot_lean_south_se tot_harvest_south tot_harvest_south_se 
		p_lean p_topup_lean p_harvest p_topup_harvest p_north p_central p_south 
		mean_y_north sd_y_north mean_y_central sd_y_central mean_y_south sd_y_south 
		r2 N, fmt(3 3 3 3 3 3 3 3 3 3 3 3 2 2 2 2 2 2 2 2 2 2 2 2 2 2 0) 
		labels("Difference: treatment households vs. households in control villages (Lean, North)" " " "Difference: treatment households vs. households in control villages (Harvest, North)" " " 
		"Difference: treatment households vs. households in control villages (Lean, Central)" " " "Difference: treatment households vs. households in control villages (Harvest, Central)" " " 
		"Difference: treatment households vs. households in control villages (Lean, South)" " " "Difference: treatment households vs. households in control villages (Harvest, South)" " " 
		"p-value: all three regions have equal effects on control households in lean treatment villages" "p-value: all three regions have equal effects on lean treatment households"
		"p-value: all three regions have equal effects on control households in harvest treatment villages" "p-value: all three regions have equal effects on harvest treatment households"
		"p-value: equal effects on lean treatment HHs and harvest treatment HHs (North)" "p-value: equal effects on lean treatment HHs and harvest treatment HHs (Central)" "p-value: equal effects on lean treatment HHs and harvest treatment HHs (South)"
		"Mean of dep. var. in control villages (North)" "S.D. of dep. var. in control villages (North)"
		"Mean of dep. var. in control villages (Central)" "S.D. of dep. var. in control villages (Central)"
		"Mean of dep. var. in control villages (South)" "S.D. of dep. var. in control villages (South)" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;	
		
	




/*-------- Mechanism ---------------------------------------------------------*/;

// Table 7: Durable Goods and Ag Inputs (Round 2);

	preserve;
	keep if round==2;
	
	foreach var of varlist $longfam_4 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
				
	foreach var of varlist $longfam_3 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp BL_`var'  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		

	
	estout EST_* using "${TABLES}table7.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table 7.  ITT on Durable Goods and Ag Inputs, with Baseline Controls (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;
	


// Table 8: Durable Goods and Ag Inputs (Round 2, by Region);

	preserve;
	keep if round==2;
	
	foreach var of varlist $longfam_4 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp_north = pwp_central = pwp_south;
			estadd scalar p_pwp = r(p);
			test topup_pwp_north = topup_pwp_central = topup_pwp_south;
			estadd scalar p_topup_pwp = r(p);
			
			foreach x in north central south {;
			
			test pwp_`x'+topup_pwp_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[pwp_`x']+_b[topup_pwp_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp_`x']+_b[topup_pwp_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
				
			qui sum `var' if e(sample) & pwp==0 & `x'==1;
			estadd scalar mean_y_`x'=r(mean);
			estadd scalar sd_y_`x'=r(sd);
			
			};
			
			};
		drop mean_`var';
		};
			
	foreach var of varlist $longfam_3 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south BL_`var' BL_`var'_north BL_`var'_central BL_`var'_south i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp_north = pwp_central = pwp_south;
			estadd scalar p_pwp = r(p);
			test topup_pwp_north = topup_pwp_central = topup_pwp_south;
			estadd scalar p_topup_pwp = r(p);
						
			foreach x in north central south {;
			
			test pwp_`x'+topup_pwp_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[pwp_`x']+_b[topup_pwp_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp_`x']+_b[topup_pwp_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			
			qui sum `var' if e(sample) & pwp==0 & `x'==1;
			estadd scalar mean_y_`x'=r(mean);
			estadd scalar sd_y_`x'=r(sd);
			
			};
			
			};
		drop mean_`var';
		};
		

	estout EST_* using "${TABLES}table8.tex", replace 
		style(tex)
		keep(pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south)
		numbers label
		title("Table 8.  ITT on Durable Goods and Ag Inputs by Region (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot_north tot_north_se tot_central tot_central_se tot_south tot_south_se p_pwp p_topup_pwp mean_y_north sd_y_north mean_y_central sd_y_central mean_y_south sd_y_south r2 N, fmt(3 3 3 3 3 3 2 2 2 2 2 2 2 2 2 0) 
		labels("Difference: treatment households vs. households in control villages (North)" " " "Difference: treatment households vs. households in control villages (Central)" " " "Difference: treatment households vs. households in control villages (South)" " " 
		"p-value: all three regions have equal effects on control households in treatment villages" "p-value: all three regions have equal effects on treatment households"
		"Mean of dep. var. in control villages (North)" "S.D. of dep. var. in control villages (North)"
		"Mean of dep. var. in control villages (Central)" "S.D. of dep. var. in control villages (Central)"
		"Mean of dep. var. in control villages (South)" "S.D. of dep. var. in control villages (South)" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;	
	

// Table 9: Price index (Round 2);
	
	// Village level	
	foreach var of varlist price_level_ea {;
		display "outcome=`var'";
		
		preserve;
		keep if ea_tag==1;
		keep if round==2;		
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			xi: reg `var' pwp   i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			};		
		drop mean_`var';
		restore;
		
		forval region=1/3 {;
		preserve;
		keep if ea_tag==1;
		keep if round==2 & region==`region';
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			xi: reg `var' pwp   i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var'_`region';
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			};
		drop mean_`var';
		restore;
			};
			};

	estout EST_* using "${TABLES}table9.tex", replace 
		style(tex)
		keep(pwp)
		numbers label
		title("Table 9.  The Effect of PWP on Village Price (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(mean_y sd_y r2 N, fmt(2 2 2 0) labels("Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
	
	estimates clear;
	
	
// Table 10: Labor Market Tightening (Round 2);

	preserve;
	keep if round==2;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
						
			xi: reg `var' pwp_nohired topup_pwp_nohired pwp_hired topup_pwp_hired any_hired i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp_nohired + topup_pwp_nohired = pwp_hired + topup_pwp_hired;
			estadd scalar p=r(p);
			
			foreach x in nohired hired {;
			
			test pwp_`x'+topup_pwp_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[pwp_`x']+_b[topup_pwp_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp_`x']+_b[topup_pwp_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			};
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			
			};
		drop mean_`var';
		};
			
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
						
			xi: reg `var' pwp_nohired topup_pwp_nohired pwp_hired topup_pwp_hired any_hired BL_`var'  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp_nohired + topup_pwp_nohired = pwp_hired + topup_pwp_hired;
			estadd scalar p=r(p);
			
			foreach x in nohired hired {;
			
			test pwp_`x'+topup_pwp_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[pwp_`x']+_b[topup_pwp_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp_`x']+_b[topup_pwp_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			};
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			
			};
		drop mean_`var';
		};

			
		estout EST_* using "${TABLES}table10.tex", replace 
		style(tex)
		keep(pwp_nohired topup_pwp_nohired pwp_hired topup_pwp_hired any_hired)
		numbers label
		title("Table 10.  Labor Market Tigentening (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot_nohired tot_nohired_se tot_hired tot_hired_se p mean_y sd_y r2 N, fmt(3 3 3 3 2 2 2 2 0) 
		labels("Difference: treatment households vs. households in control villages (No hired labor)" " " "Difference: harvest treatment households vs. households in control villages (Hired labor)" " " 
				"p-value: equal effects on treatment HHs with hired labor and treatment HHs without hired labor" "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;

	restore;
	
	estimates clear;


	
// Table 11: Other Program Participation and Transfer/Loan (Round 2);

	preserve;
	keep if round==2;
		
	foreach var of varlist $longfam_5 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp BL_`var'  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		
	foreach var of varlist $longfam_6 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		
	
	estout EST_* using "${TABLES}table11.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table 11.  ITT on Other Program Participation and Transfer/Loan, with Baseline Controls (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;



***************************************************;
***** Appendix  ***********************************;
***************************************************;


/*-------- Balance Test ------------------------------------------------------*/;

// Table A1: Food Security and Labor Supply by Region;
	
	// North
	preserve;
	keep if round==0 & region==1;
	
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}tableA1.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A1.  Balance Test on Food Security and Labor Supply by Region (IHS3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;

	restore;

	estimates clear;
	
	// Central
	preserve;
	keep if round==0 & region==2;
	
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}tableA1.tex", append 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A1.  Balance Test on Food Security and Labor Supply by Region (IHS3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;

	restore;
	
	estimates clear;
	
	// South
	preserve;
	keep if round==0 & region==3;
	
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}tableA1.tex", append 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A1.  Balance Test on Food Security and Labor Supply by Region (IHS3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;

	restore;

	estimates clear;


// Table A2: Other HH Characteristics;

	preserve;
	keep if round==0;
	
	*looping over other HH characteristics;
	foreach var of varlist $longfam_Y {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}tableA2.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A2.  Balance Test on Other HH Characteristics (IHS3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;

	restore;

	estimates clear;



/*-------- ITT ---------------------------------------------------------------*/;



// Table A3: Full sample without baseline controls, Round 2 and 3;	

	// Round 2
	preserve;
	keep if round==2;
		
	foreach var of varlist $longfam_2 $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}tableA3.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A3.  ITT on Food Security and Labor Supply, Full Sample without Baseline Controls (Round 2 and 3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;
	
	// Round 3
	preserve;
	keep if round==3;
		
	foreach var of varlist $longfam_2 $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' lean topup_lean harvest topup_harvest i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test lean + topup_lean = harvest + topup_harvest;
			estadd scalar p=r(p);
			
			foreach x in lean harvest {;
			
			test `x'+topup_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[`x']+_b[topup_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[`x']+_b[topup_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			};
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			
			};
		drop mean_`var';
		};
	
	estout EST_* using "${TABLES}tableA3.tex", append 
		style(tex)
		keep(lean topup_lean harvest topup_harvest)
		numbers label
		title("Table A3.  ITT on Food Security and Labor Supply, Full Sample without Baseline Controls (Round 2 and 3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot_lean tot_lean_se tot_harvest tot_harvest_se p mean_y sd_y r2 N, fmt(3 3 3 3 2 2 2 2 0) 
		labels("Difference: lean treatment households vs. households in control villages" " " "Difference: harvest treatment households vs. households in control villages" " " 
				"p-value: equal effects on lean treatment HHs and harvest treatment HHs" "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;

	
// Table A4: Baseline subsample without baseline controls, Round 2 and 3;	

	// Round 2
	preserve;
	keep if round==2;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
				
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		

	estout EST_* using "${TABLES}tableA4.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A4.  ITT on Food Security and Labor Supply, Baseline Subsample without Baseline Controls (Round 2 and 3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;
	
	// Round 3
	preserve;
	keep if round==3;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' lean topup_lean harvest topup_harvest i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test lean + topup_lean = harvest + topup_harvest;
			estadd scalar p=r(p);
			
			foreach x in lean harvest {;
			
			test `x'+topup_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[`x']+_b[topup_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[`x']+_b[topup_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			};
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			
			};
		drop mean_`var';
		};	
		
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' lean topup_lean harvest topup_harvest i.hh_a01 i.week i.year if BL_`var', robust cl(ea_id) ;
			estimates store EST_`var';
			
			test lean + topup_lean = harvest + topup_harvest;
			estadd scalar p=r(p);
			
			foreach x in lean harvest {;
			
			test `x'+topup_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[`x']+_b[topup_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[`x']+_b[topup_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			};
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);
			
			};
		drop mean_`var';
		};
		

		
	estout EST_* using "${TABLES}tableA4.tex", append 
		style(tex)
		keep(lean topup_lean harvest topup_harvest)
		numbers label
		title("Table A4.  ITT on Food Security and Labor Supply, Baseline Subsample without Baseline Controls (Round 2 and 3)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot_lean tot_lean_se tot_harvest tot_harvest_se p mean_y sd_y r2 N, fmt(3 3 3 3 2 2 2 2 0) 
		labels("Difference: lean treatment households vs. households in control villages" " " "Difference: harvest treatment households vs. households in control villages" " " 
				"p-value: equal effects on lean treatment HHs and harvest treatment HHs" "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;
	
// Table A5: Round 2, by Region (including addtional HH characteristics);

	preserve;
	keep if round==2;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south $longfam_8 i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp_north = pwp_central = pwp_south;
			estadd scalar p_pwp = r(p);
			test topup_pwp_north = topup_pwp_central = topup_pwp_south;
			estadd scalar p_topup_pwp = r(p);
			
			foreach x in north central south {;
			
			test pwp_`x'+topup_pwp_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[pwp_`x']+_b[topup_pwp_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp_`x']+_b[topup_pwp_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			
			qui sum `var' if e(sample) & pwp==0 & `x'==1;
			estadd scalar mean_y_`x'=r(mean);
			estadd scalar sd_y_`x'=r(sd);
			
			};
			
			};
		drop mean_`var';
		};
			
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south BL_`var' BL_`var'_north BL_`var'_central BL_`var'_south $longfam_8 i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			
			test pwp_north = pwp_central = pwp_south;
			estadd scalar p_pwp = r(p);
			test topup_pwp_north = topup_pwp_central = topup_pwp_south;
			estadd scalar p_topup_pwp = r(p);
			
			foreach x in north central south {;
			
			test pwp_`x'+topup_pwp_`x'=0;
			local p_`x'=r(p);
			
			nlcom _b[pwp_`x']+_b[topup_pwp_`x'];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp_`x']+_b[topup_pwp_`x'];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p_`x''<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p_`x''<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_`x'_se = temp_se;
			estadd local tot_`x' = temp_mean;
			
			drop temp1 temp2 temp3 temp4;
			scalar drop v1 v2 temp_se temp_mean;
			mat drop v;
			
			qui sum `var' if e(sample) & pwp==0 & `x'==1;
			estadd scalar mean_y_`x'=r(mean);
			estadd scalar sd_y_`x'=r(sd);
			
			};
			
			};
		drop mean_`var';
		};
		

	estout EST_* using "${TABLES}tableA5.tex", replace 
		style(tex)
		keep(pwp_north topup_pwp_north pwp_central topup_pwp_central pwp_south topup_pwp_south)
		numbers label
		title("Table A5.  ITT on Food Security and Labor Supply by Region (Round 2, including addtional HH chars)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot_north tot_north_se tot_central tot_central_se tot_south tot_south_se p_pwp p_topup_pwp mean_y_north sd_y_north mean_y_central sd_y_central mean_y_south sd_y_south r2 N, fmt(3 3 3 3 3 3 2 2 2 2 2 2 2 2 2 0) 
		labels("Difference: treatment households vs. households in control villages (North)" " " "Difference: treatment households vs. households in control villages (Central)" " " "Difference: treatment households vs. households in control villages (South)" " " 
		"p-value: all three regions have equal effects on control households in treatment villages" "p-value: all three regions have equal effects on treatment households"
		"Mean of dep. var. in control villages (North)" "S.D. of dep. var. in control villages (North)"
		"Mean of dep. var. in control villages (Central)" "S.D. of dep. var. in control villages (Central)"
		"Mean of dep. var. in control villages (South)" "S.D. of dep. var. in control villages (South)" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;	
	
	
// Table A6: All three specifications, Round 2, North;

	preserve;
	keep if round==2 & region==1;
	
	// Full sample, no baseline controls;

	foreach var of varlist $longfam_2 $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}tableA6.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A6.  ITT on Food Security and Labor Supply (All Specifications, Round 2, North)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
		
	// Baseline subsample, no baseline controls;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		
	estout EST_* using "${TABLES}tableA6.tex", append 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A6.  ITT on Food Security and Labor Supply (All Specifications, Round 2, North)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
		
	// Baseline subsample, including baseline controls;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};		
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp BL_`var'  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		
	estout EST_* using "${TABLES}tableA6.tex", append 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A6.  ITT on Food Security and Labor Supply (All Specifications, Round 2, North)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;



// Table A7: All three specifications, Round 2, Central;

	preserve;
	keep if round==2 & region==2;
	
	// Full sample, no baseline controls;

	foreach var of varlist $longfam_2 $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}tableA7.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A7.  ITT on Food Security and Labor Supply (All Specifications, Round 2, Central)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
		
	// Baseline subsample, no baseline controls;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		
	estout EST_* using "${TABLES}tableA7.tex", append 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A7.  ITT on Food Security and Labor Supply (All Specifications, Round 2, Central)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
		
	// Baseline subsample, including baseline controls;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
				
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp BL_`var'  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		
	estout EST_* using "${TABLES}tableA7.tex", append 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A7.  ITT on Food Security and Labor Supply (All Specifications, Round 2, Central)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;




// Table A8: All three specifications, Round 2, South;

	preserve;
	keep if round==2 & region==3;
	
	// Full sample, no baseline controls;

	foreach var of varlist $longfam_2 $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
	
	estout EST_* using "${TABLES}tableA8.tex", replace 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A8.  ITT on Food Security and Labor Supply (All Specifications, Round 2, South)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
		
	// Baseline subsample, no baseline controls;

	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};	
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		
	estout EST_* using "${TABLES}tableA8.tex", append 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A8.  ITT on Food Security and Labor Supply (All Specifications, Round 2, South)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
		
	// Baseline subsample, including baseline controls;
	
	foreach var of varlist $longfam_2 {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
				
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			
			xi: reg `var' pwp topup_pwp BL_`var'  i.hh_a01 i.week i.year if BL_`var'!=., robust cl(ea_id) ;
			estimates store EST_`var';
			test pwp+topup_pwp=0;
			local p=r(p);
			
			nlcom _b[pwp]+_b[topup_pwp];
			mat v=r(V);
			scalar v1=v[1,1];
			scalar v2=sqrt(v1);
			gen temp1=v2;
			gen temp2=_b[pwp]+_b[topup_pwp];
			egen temp3 = concat(temp1), format(%9.3f);
			egen temp4 = concat(temp2), format(%9.3f);
			
			replace temp3 = "(" + temp3 + ")";		
			
			if `p'<=0.1 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.05 {;
			replace temp4 = temp4 + "*";
			};
			if `p'<=0.01 {;
			replace temp4 = temp4 + "*";
			};
			
			scalar temp_se = temp3;
			scalar temp_mean = temp4;
			estadd local tot_se = temp_se;
			estadd local tot = temp_mean;
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);

			};
		drop mean_`var' temp1 temp2 temp3 temp4;
		scalar drop v1 v2 temp_se temp_mean;
		mat drop v;
		};
		

	estout EST_* using "${TABLES}tableA8.tex", append 
		style(tex)
		keep(pwp topup_pwp)
		numbers label
		title("Table A8.  ITT on Food Security and Labor Supply (All Specifications, Round 2, South)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(tot tot_se mean_y sd_y r2 N, fmt(3 3 2 2 2 0) labels("Difference: treatment households vs. households in control villages" " " "Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "R-squared" "Observations")) legend 		
		;
			
	restore;

	estimates clear;


/*-------- Take-up -----------------------------------------------------------*/;

// Table A9: Program Take-up;

preserve;

keep if inrange(round,1,3);
keep if non_ihs3EA==0;

tabstat anyMasaf if pwp==0, stat(mean n) by(round);
tabstat anyMasaf if pwp==1 & topup_pwp==0, stat(mean n) by(round);
tabstat anyMasaf if topup_pwp==1, stat(mean n) by(round);

foreach x in north central south {;

	di "`x'";
	tabstat anyMasaf if pwp==0 & `x'==1, stat(mean n) by(round);
	tabstat anyMasaf if pwp==1 & topup_pwp==0 & `x'==1, stat(mean n) by(round);
	tabstat anyMasaf if topup_pwp==1 & `x'==1, stat(mean n) by(round);
	
	};
	
restore;


/*-------- TOT (IV) ----------------------------------------------------------*/;

// Table A10: Food Security and Labor Supply, Round 2;

	preserve;
	keep if round==2;
	
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			ivregress 2sls `var' (anyMasaf = pwp)  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);			
			
			};
		drop mean_`var';
		};
		
	// first-stage;
	reg anyMasaf pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
	test pwp = 0;
	local F = r(F);
	
	estout EST_* using "${TABLES}tableA10.tex", replace 
		style(tex)
		keep(anyMasaf)
		numbers label
		title("Table A10.  TOT Effect on Food Security and Labor Supply (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(mean_y sd_y N, fmt(2 2 0) labels("Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "Observations")) legend
 		note("Frist-stage F-statistics is `F'.")
		;	
	
	restore;
	
	estimates clear;
	

// Table A11: Food Security and Labor Supply, by Region, Round 2;
	
	// north
	preserve;
	keep if round==2 & region==1;
	
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			ivregress 2sls `var' (anyMasaf = pwp)  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);				
			
			};
		drop mean_`var';
		};
	
	// first-stage;
	reg anyMasaf pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
	test pwp = 0;
	local F = r(F);
	
	estout EST_* using "${TABLES}tableA11.tex", replace 
		style(tex)
		keep(anyMasaf)
		numbers label
		title("Table A11.  TOT Effect on Food Security and Labor Supply, by Region (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(mean_y sd_y N, fmt(2 2 0) labels("Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "Observations")) legend 		
 		note("Frist-stage F-statistics is `F'.")
		;	
	
	restore;
	
	estimates clear;

	// central
	preserve;
	keep if round==2 & region==2;
	
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			ivregress 2sls `var' (anyMasaf = pwp)  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);				
			
			};
		drop mean_`var';
		};
		
	// first-stage;
	reg anyMasaf pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
	test pwp = 0;
	local F = r(F);
	
	estout EST_* using "${TABLES}tableA11.tex", append 
		style(tex)
		keep(anyMasaf)
		numbers label
		title("Table A11.  TOT Effect on Food Security and Labor Supply, by Region (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(mean_y sd_y N, fmt(2 2 0) labels("Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "Observations")) legend 		
 		note("Frist-stage F-statistics is `F'.")
		;	
	
	restore;
	
	estimates clear;

	//south
	preserve;
	keep if round==2 & region==3;
	
	foreach var of varlist $longfam_X {;
		display "outcome=`var'";
		egen mean_`var'=mean(`var');
			if mean_`var'!=. {; 
			ivregress 2sls `var' (anyMasaf = pwp)  i.hh_a01 i.week i.year, robust cl(ea_id) ;
			estimates store EST_`var';
			
			qui sum `var' if e(sample) & pwp==0;
			estadd scalar mean_y=r(mean);
			estadd scalar sd_y=r(sd);				
			
			};
		drop mean_`var';
		};

	// first-stage;
	reg anyMasaf pwp i.hh_a01 i.week i.year, robust cl(ea_id) ;
	test pwp = 0;
	local F = r(F);
	
	estout EST_* using "${TABLES}tableA11.tex", append 
		style(tex)
		keep(anyMasaf)
		numbers label
		title("Table A11.  TOT Effect on Food Security and Labor Supply, by Region (Round 2)", @title)
		collabels(, none) mlabels(, dep)
		posthead("") varwidth(30) modelwidth(10)
		cells(b(star fmt(3)) se(par)) starlevels(* 0.10 ** 0.05 *** 0.001) 
		stats(mean_y sd_y N, fmt(2 2 0) labels("Mean of dep. var. in control villages" "S.D. of dep. var. in control villages" "Observations")) legend 		
 		note("Frist-stage F-statistics is `F'.")
		;	
	
	restore;
	
	estimates clear;
	

log close;
	
exit;
